slepc-3.18.0 2022-10-01
Report Typos and Errors

## SLEPc System routines

SLEPc provides a variety of "system" level routines. These routines are generally tools used by other SLEPc routines and are not intended for application programmers (except the basic SlepcInitialize() / SlepcFinalize()).

Useful tools for application programmers can be found in PETSc's system routines, including parallel file access, synchronized printing to screen, and many other programming aids.

Beginner - Basic usage
| SlepcFinalize | SlepcInitializeFortran |
SlepcInitialize | SlepcInitialized |
Intermediate - Setting options for algorithms and data structures
| SlepcGetVersion | SlepcGetVersionNumber | SlepcHasExternalPackage
Advanced - Setting more advanced options and customization
| SlepcInitializeNoArguments | SlepcInitializeNoPointers |
Developer - Interfaces intended primarily for library developers, not for typical applications programmers
| MatCreateTile | SlepcSCCompare | VecCheckOrthonormality
MatCreateVecsEmpty | SlepcSNPrintfScalar | VecCompGetSubVecs
MatNormEstimate | SlepcSortEigenvalues | VecCompSetSubVecs
SlepcAbs | SlepcVecPoolCreate | VecCreateComp
SlepcAbsEigenvalue | SlepcVecPoolDestroy | VecCreateCompWithVecs
SlepcFinalized | SlepcVecPoolGetVecs | VecDuplicateEmpty
SlepcHeaderCreate | SlepcVecPoolRestoreVecs | VecNormalizeComplex
SlepcSC | VecCheckOrthogonality | VecSetRandomNormal
No deprecated routines

Table of Contents